@@ -30,7 +30,6 @@ class TaskMetadata():
             "PartitionKey": self.pk,
             "RowKey": self.rk,
             "BlobName": self.blob_name,
-            "Params": self.params,
             "Request": self.request,
             "Result": self.result,
             "State": self.state,
@@ -42,6 +41,8 @@ class TaskMetadata():
         }
         if self.next_batch is not None:
             row['NextChunk'] = json.dumps(self.next_batch, ensure_ascii=False)
+        if self.params is not None:
+            row['Params'] = json.dumps(self.params, ensure_ascii=False)
         return row
 
     @staticmethod
