@@ -412,12 +412,12 @@ class Worker:
         # Start reading new batch asynchrounously
         batch_read_task = self.pool.apply_async(self.reader.read_next_batch, args=(
             metadata.blob_name, 
-            metadata.offset + len(metadata.next_chunk), 
+            metadata.offset + len(metadata.next_batch), 
             self.segment_limit 
         )) 
 
         # Process current batch
-        result, failures = func(metadata.next_chunk, metadata.params)
+        result, failures = func(metadata.next_batch, metadata.params)
         
         # Set correct segment indeces, based on offset
         for i in range(len(failures)):
